import React from 'react'
import styled from 'styled-components'
import { groupBy, get } from 'lodash'
import { th } from '@pubsweet/ui-toolkit'
import { compose, withState, withHandlers, withProps } from 'recompose'

import {
  Row,
  Item,
  Text,
  AuthorTag,
  ActionLink,
  AuthorWithTooltip,
} from 'pubsweet-component-faraday-ui'

const parseAffiliationGroup = (authors = []) => {
  const affiliationGroup = groupBy(authors, 'affiliation')
  const affiliationList = Object.keys(affiliationGroup)
  const list = affiliationList.reduce((acc, el, index) => {
    const authorGroup = affiliationGroup[el].map(i => {
      i.affiliationNumber = index + 1
      return i
    })
    return [...authorGroup, ...acc]
  }, [])

  return {
    list,
    affiliationList,
  }
}

const AuthorTagList = ({
  authors = [],
  affiliationList,
  separator = ',',
  authorKey = 'email',
  withTooltip = false,
  withAffiliations = false,
  showAffiliation = false,
  toggleAffiliation,
}) => (
  <Root>
    {authors
      .map(
        a =>
          withTooltip ? (
            <AuthorWithTooltip author={a} key={a[authorKey]} />
          ) : (
            <AuthorTag author={a} key={a[authorKey]} />
          ),
      )
      .reduce(
        (prev, curr, index) =>
          index === 0
            ? [prev, curr]
            : [prev, separator, <span key={curr}>&nbsp;</span>, curr],
        [],
      )}
    {withAffiliations && (
      <Item ml={1}>
        {showAffiliation ? (
          <ActionLink icon="minus" onClick={toggleAffiliation(false)}>
            Hide Affiliations
          </ActionLink>
        ) : (
          <ActionLink icon="plus" onClick={toggleAffiliation(true)}>
            Show Affiliations
          </ActionLink>
        )}
      </Item>
    )}

    {withAffiliations &&
      showAffiliation && (
        <AffiliationRow>
          {affiliationList.map((a, i) => (
            <Item flex={1} key={a}>
              <Superscript>{i + 1}</Superscript>
              <Text>{a}</Text>
            </Item>
          ))}
        </AffiliationRow>
      )}
  </Root>
)
export default compose(
  withState('showAffiliation', 'setAffiliation', false),
  withProps(({ authors = [], withAffiliations }) => ({
    authors: withAffiliations
      ? get(parseAffiliationGroup(authors), 'list', [])
      : authors,
    affiliationList:
      withAffiliations &&
      get(parseAffiliationGroup(authors), 'affiliationList', []),
  })),
  withHandlers({
    toggleAffiliation: ({ setAffiliation }) => value => () =>
      setAffiliation(value),
  }),
)(AuthorTagList)

// #region styles
const Root = styled.div`
  align-items: center;
  display: flex;
  flex-flow: row wrap;

  font-family: ${th('fontReading')};
`
const AffiliationRow = styled(Row)`
  border-left: 1px solid ${th('colorBackgroundHue')};
  padding-left: ${th('gridUnit')};
  flex-direction: column;
`
const Superscript = styled.span`
  position: relative;
  top: -0.5em;
  font-size: 80%;
  font-family: ${th('fontInterface')};
`
// #endregion
