import React, { Fragment } from 'react'
import { Text, FileItem, Item, Row } from 'pubsweet-component-faraday-ui'

import { withFilePreview, withFileDownload } from '../helpers'

const ManuscriptFileList = ({
  files: { manuscripts = [], coverLetter = [], supplementary = [] },
  previewFile,
  downloadFile,
  ...rest
}) => (
  <Fragment>
    {!!manuscripts.length && (
      <Fragment>
        <Text labelLine mb={1} mt={1}>
          MAIN MANUSCRIPT
        </Text>
        <Row justify="flex-start" mb={1}>
          {manuscripts.map(file => (
            <Item
              alignItems="flex-start"
              flex={0}
              key={file.id}
              mr={1}
              vertical
            >
              <FileItem
                item={file}
                onDownload={downloadFile}
                onPreview={previewFile}
                {...rest}
                mb={1}
              />
            </Item>
          ))}
        </Row>
      </Fragment>
    )}
    {!!supplementary.length && (
      <Fragment>
        <Text labelLine mb={1} mt={2}>
          SUPPLEMENTARY FILES
        </Text>
        <Row justify="flex-start" mb={1}>
          {supplementary.map(file => (
            <Item
              alignItems="flex-start"
              flex={0}
              key={file.id}
              mr={1}
              vertical
            >
              <FileItem
                item={file}
                onDownload={downloadFile}
                onPreview={previewFile}
                {...rest}
                mb={1}
              />
            </Item>
          ))}
        </Row>
      </Fragment>
    )}
    {!!coverLetter.length && (
      <Fragment>
        <Text labelLine mb={1} mt={2}>
          COVER LETTER
        </Text>
        <Row justify="flex-start" mb={1}>
          {coverLetter.map(file => (
            <Item
              alignItems="flex-start"
              flex={0}
              key={file.id}
              mr={1}
              vertical
            >
              <FileItem
                item={file}
                onDownload={downloadFile}
                onPreview={previewFile}
                {...rest}
                mb={1}
              />
            </Item>
          ))}
        </Row>
      </Fragment>
    )}
  </Fragment>
)

export default withFilePreview(withFileDownload(ManuscriptFileList))
